# FvwmCommand.sh
# Collection of fvwm builtin commands for FvwmCommand
#
alias FvwmCommand='/usr/X11R6/bin/FvwmCommand'
XorValue () {
	FvwmCommand "XorValue $*"
}
XorPixmap () {
	FvwmCommand "XorPixmap $*"
}
XineramaSlsSize () {
	FvwmCommand "XineramaSlsSize $*"
}
XineramaSls () {
	FvwmCommand "XineramaSls $*"
}
XineramaPrimaryScreen () {
	FvwmCommand "XineramaPrimaryScreen $*"
}
Xinerama () {
	FvwmCommand "Xinerama $*"
}
WindowShadeAnimate () {
	FvwmCommand "WindowShadeAnimate $*"
}
WindowShade () {
	FvwmCommand "WindowShade $*"
}
WindowList () {
	FvwmCommand "WindowList $*"
}
WindowId () {
	FvwmCommand "WindowId $*"
}
WindowFont () {
	FvwmCommand "WindowFont $*"
}
WarpToWindow () {
	FvwmCommand "WarpToWindow $*"
}
Wait () {
	FvwmCommand "Wait $*"
}
UpdateStyles () {
	FvwmCommand "UpdateStyles $*"
}
UpdateDecor () {
	FvwmCommand "UpdateDecor $*"
}
UnsetEnv () {
	FvwmCommand "UnsetEnv $*"
}
TitleStyle () {
	FvwmCommand "TitleStyle $*"
}
Title () {
	FvwmCommand "Title $*"
}
ThisWindow () {
	FvwmCommand "ThisWindow $*"
}
Style () {
	FvwmCommand "Style $*"
}
StrokeFunc () {
	FvwmCommand "StrokeFunc $*"
}
Stroke () {
	FvwmCommand "Stroke $*"
}
Stick () {
	FvwmCommand "Stick $*"
}
SnapGrid () {
	FvwmCommand "SnapGrid $*"
}
SnapAttraction () {
	FvwmCommand "SnapAttraction $*"
}
Silent () {
	FvwmCommand "Silent $*"
}
SetEnv () {
	FvwmCommand "SetEnv $*"
}
SetAnimation () {
	FvwmCommand "SetAnimation $*"
}
set_sync_mask () {
	FvwmCommand "set_sync_mask $*"
}
set_nograb_mask () {
	FvwmCommand "set_nograb_mask $*"
}
set_mask () {
	FvwmCommand "set_mask $*"
}
SendToModule () {
	FvwmCommand "SendToModule $*"
}
Send_WindowList () {
	FvwmCommand "Send_WindowList $*"
}
Send_ConfigInfo () {
	FvwmCommand "Send_ConfigInfo $*"
}
Scroll () {
	FvwmCommand "Scroll $*"
}
SaveSession () {
	FvwmCommand "SaveSession $*"
}
SaveQuitSession () {
	FvwmCommand "SaveQuitSession $*"
}
Restart () {
	FvwmCommand "Restart $*"
}
ResizeMove () {
	FvwmCommand "ResizeMove $*"
}
Resize () {
	FvwmCommand "Resize $*"
}
Repeat () {
	FvwmCommand "Repeat $*"
}
RefreshWindow () {
	FvwmCommand "RefreshWindow $*"
}
Refresh () {
	FvwmCommand "Refresh $*"
}
RecaptureWindow () {
	FvwmCommand "RecaptureWindow $*"
}
Recapture () {
	FvwmCommand "Recapture $*"
}
Read () {
	FvwmCommand "Read $*"
}
RaiseLower () {
	FvwmCommand "RaiseLower $*"
}
Raise () {
	FvwmCommand "Raise $*"
}
QuitSession () {
	FvwmCommand "QuitSession $*"
}
QuitScreen () {
	FvwmCommand "QuitScreen $*"
}
Quit () {
	FvwmCommand "Quit $*"
}
Prev () {
	FvwmCommand "Prev $*"
}
Popup () {
	FvwmCommand "Popup $*"
}
PointerKey () {
	FvwmCommand "PointerKey $*"
}
PlaceAgain () {
	FvwmCommand "PlaceAgain $*"
}
PixmapPath () {
	FvwmCommand "PixmapPath $*"
}
PipeRead () {
	FvwmCommand "PipeRead $*"
}
Pick () {
	FvwmCommand "Pick $*"
}
OpaqueMoveSize () {
	FvwmCommand "OpaqueMoveSize $*"
}
Nop () {
	FvwmCommand "Nop $*"
}
None () {
	FvwmCommand "None $*"
}
Next () {
	FvwmCommand "Next $*"
}
MoveToScreen () {
	FvwmCommand "MoveToScreen $*"
}
MoveToPage () {
	FvwmCommand "MoveToPage $*"
}
MoveToDesk () {
	FvwmCommand "MoveToDesk $*"
}
MoveThreshold () {
	FvwmCommand "MoveThreshold $*"
}
Move () {
	FvwmCommand "Move $*"
}
Mouse () {
	FvwmCommand "Mouse $*"
}
ModuleTimeout () {
	FvwmCommand "ModuleTimeout $*"
}
ModuleSynchronous () {
	FvwmCommand "ModuleSynchronous $*"
}
ModulePath () {
	FvwmCommand "ModulePath $*"
}
Module () {
	FvwmCommand "Module $*"
}
MenuStyle () {
	FvwmCommand "MenuStyle $*"
}
Menu () {
	FvwmCommand "Menu $*"
}
Maximize () {
	FvwmCommand "Maximize $*"
}
Lower () {
	FvwmCommand "Lower $*"
}
Layer () {
	FvwmCommand "Layer $*"
}
KillModule () {
	FvwmCommand "KillModule $*"
}
Key () {
	FvwmCommand "Key $*"
}
ImagePath () {
	FvwmCommand "ImagePath $*"
}
IgnoreModifiers () {
	FvwmCommand "IgnoreModifiers $*"
}
IconPath () {
	FvwmCommand "IconPath $*"
}
Iconify () {
	FvwmCommand "Iconify $*"
}
IconFont () {
	FvwmCommand "IconFont $*"
}
HilightColorset () {
	FvwmCommand "HilightColorset $*"
}
HilightColor () {
	FvwmCommand "HilightColor $*"
}
HideGeometryWindow () {
	FvwmCommand "HideGeometryWindow $*"
}
GotoPage () {
	FvwmCommand "GotoPage $*"
}
GotoDeskAndPage () {
	FvwmCommand "GotoDeskAndPage $*"
}
GotoDesk () {
	FvwmCommand "GotoDesk $*"
}
GnomeShowDesks () {
	FvwmCommand "GnomeShowDesks $*"
}
GnomeButton () {
	FvwmCommand "GnomeButton $*"
}
GlobalOpts () {
	FvwmCommand "GlobalOpts $*"
}
Function () {
	FvwmCommand "Function $*"
}
Focus () {
	FvwmCommand "Focus $*"
}
FlipFocus () {
	FvwmCommand "FlipFocus $*"
}
FakeClick () {
	FvwmCommand "FakeClick $*"
}
ExecUseShell () {
	FvwmCommand "ExecUseShell $*"
}
Exec () {
	FvwmCommand "Exec $*"
}
EscapeFunc () {
	FvwmCommand "EscapeFunc $*"
}
Emulate () {
	FvwmCommand "Emulate $*"
}
EdgeThickness () {
	FvwmCommand "EdgeThickness $*"
}
EdgeScroll () {
	FvwmCommand "EdgeScroll $*"
}
EdgeResistance () {
	FvwmCommand "EdgeResistance $*"
}
Echo () {
	FvwmCommand "Echo $*"
}
Direction () {
	FvwmCommand "Direction $*"
}
DestroyStyle () {
	FvwmCommand "DestroyStyle $*"
}
DestroyModuleConfig () {
	FvwmCommand "DestroyModuleConfig $*"
}
DestroyMenuStyle () {
	FvwmCommand "DestroyMenuStyle $*"
}
DestroyMenu () {
	FvwmCommand "DestroyMenu $*"
}
DestroyFunc () {
	FvwmCommand "DestroyFunc $*"
}
DestroyDecor () {
	FvwmCommand "DestroyDecor $*"
}
Destroy () {
	FvwmCommand "Destroy $*"
}
DesktopSize () {
	FvwmCommand "DesktopSize $*"
}
Desk () {
	FvwmCommand "Desk $*"
}
Delete () {
	FvwmCommand "Delete $*"
}
DefaultLayers () {
	FvwmCommand "DefaultLayers $*"
}
DefaultIcon () {
	FvwmCommand "DefaultIcon $*"
}
DefaultFont () {
	FvwmCommand "DefaultFont $*"
}
DefaultColorset () {
	FvwmCommand "DefaultColorset $*"
}
DefaultColors () {
	FvwmCommand "DefaultColors $*"
}
CursorStyle () {
	FvwmCommand "CursorStyle $*"
}
CursorMove () {
	FvwmCommand "CursorMove $*"
}
Current () {
	FvwmCommand "Current $*"
}
CopyMenuStyle () {
	FvwmCommand "CopyMenuStyle $*"
}
Colorset () {
	FvwmCommand "Colorset $*"
}
ColormapFocus () {
	FvwmCommand "ColormapFocus $*"
}
ColorLimit () {
	FvwmCommand "ColorLimit $*"
}
Close () {
	FvwmCommand "Close $*"
}
ClickTime () {
	FvwmCommand "ClickTime $*"
}
ChangeMenuStyle () {
	FvwmCommand "ChangeMenuStyle $*"
}
ChangeDecor () {
	FvwmCommand "ChangeDecor $*"
}
ButtonStyle () {
	FvwmCommand "ButtonStyle $*"
}
ButtonState () {
	FvwmCommand "ButtonState $*"
}
BusyCursor () {
	FvwmCommand "BusyCursor $*"
}
BugOpts () {
	FvwmCommand "BugOpts $*"
}
BorderStyle () {
	FvwmCommand "BorderStyle $*"
}
Beep () {
	FvwmCommand "Beep $*"
}
AnimatedMove () {
	FvwmCommand "AnimatedMove $*"
}
All () {
	FvwmCommand "All $*"
}
AddToMenu () {
	FvwmCommand "AddToMenu $*"
}
AddToFunc () {
	FvwmCommand "AddToFunc $*"
}
AddToDecor () {
	FvwmCommand "AddToDecor $*"
}
AddTitleStyle () {
	FvwmCommand "AddTitleStyle $*"
}
AddButtonStyle () {
	FvwmCommand "AddButtonStyle $*"
}
Plus () {
	FvwmCommand "Plus $*"
}
AM () { 
	FvwmCommand "+ $*"
}
